<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="134"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="135"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="137"/>
        <source>Lightweight file manager</source>
        <translation>Gestionnaire de fichiers léger</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="138"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="143"/>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>Gestionnaire de fichiers de PCMan

Copyright © 2009 - 2015 洪任諭 (Hong Jen Yee)

Ce programme est un logiciel libre ; vous pouvez le redistribuer ou le modifier suivant les termes de la “GNU General Public License” telle que publiée par la Free Software Foundation, soit en version 2, soit (à votre gré) toute version ultérieure.

Ce programme est distribué dans l&apos;espoir qu&apos;il vous sera utile, mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de COMMERCIALISABILITÉ, ni d’ADÉQUATION À UN OBJECTIF PARTICULIER. Consultez la Licence Générale Publique GNU pour plus de détails.

Vous devriez avoir reçu une copie de la licence publique générale GNU avec ce programme ; si ce n&apos;est pas le cas, écrivez à la fondation pour le logiciel libre à l&apos;adresse ci-dessous :
Free Software Foundation, Inc.n 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301, USA.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://pcmanfm.sourceforge.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://pcmanfm.sourceforge.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://pcmanfm.sourceforge.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://pcmanfm.sourceforge.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="139"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programmation :
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="142"/>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <source>PCMan File Manager

Copyright (C) 2009 - 2013 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="vanished">Gestionnaire de fichiers de PCMan

Copyright © 2009 - 2015 洪任諭 (Hong Jen Yee)

Ce programme est un logiciel libre ; vous pouvez le redistribuer ou le modifier suivant les termes de la “GNU General Public License” telle que publiée par la Free Software Foundation, soit en version 2, soit (à votre gré) toute version ultérieure.

Ce programme est distribué dans l&apos;espoir qu&apos;il vous sera utile, mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de COMMERCIALISABILITÉ, ni d’ADÉQUATION À UN OBJECTIF PARTICULIER. Consultez la Licence Générale Publique GNU pour plus de détails.

Vous devriez avoir reçu une copie de la licence publique générale GNU avec ce programme ; si ce n&apos;est pas le cas, écrivez à la fondation pour le logiciel libre à l&apos;adresse ci-dessous :
Free Software Foundation, Inc.n 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301, USA.</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="160"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="110"/>
        <source>Removable medium is inserted</source>
        <translation>Un média amovible a été inséré</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="112"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Un média amovible a été inséré&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="113"/>
        <source>Type of medium:</source>
        <translation>Type de média :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="114"/>
        <source>Detecting...</source>
        <translation>Détection en cours…</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="115"/>
        <source>Please select the action you want to perform:</source>
        <translation>Veuillez sélectionner l&apos;action que vous voulez effectuer :</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="75"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="76"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="77"/>
        <source>Desktop folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="79"/>
        <source>Image file</source>
        <translation>Fichier image</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="84"/>
        <source>Folder path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="85"/>
        <source>&amp;Browse</source>
        <translation>&amp;Parcourir</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="254"/>
        <source>Desktop Preferences</source>
        <translation>Préférences du bureau</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="255"/>
        <source>Background</source>
        <translation>Arrière-plan</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="256"/>
        <source>Wallpaper mode:</source>
        <translation>Mode du fond d&apos;écran :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="257"/>
        <source>Wallpaper image file:</source>
        <translation>Fichier image du fond d&apos;écran :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="259"/>
        <source>Select background color:</source>
        <translation>Sélectionnez la couleur d&apos;arrière-plan :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="261"/>
        <source>Image file</source>
        <translation>Fichier image</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="266"/>
        <source>Image file path</source>
        <translation>Chemin du fichier image</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="267"/>
        <source>&amp;Browse</source>
        <translation>&amp;Parcourir</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="268"/>
        <source>Label Text</source>
        <translation>Texte de l&apos;étiquette</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="271"/>
        <source>Select  text color:</source>
        <translation>Sélectionnez la couleur du texte :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="272"/>
        <source>Select shadow color:</source>
        <translation>Sélectionnez la couleur de l&apos;ombre :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="273"/>
        <source>Select font:</source>
        <translation>Sélectionnez la police :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="275"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="276"/>
        <source>Window Manager</source>
        <translation>Gestionnaire de fenêtre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="277"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>Afficher les menus fournis par les gestionnaires de fenêtres lorsqu&apos;on clique sur le bureau</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="278"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="557"/>
        <source>File Manager</source>
        <translation>Gestionnaire de fichiers</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="560"/>
        <source>Go Up</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="562"/>
        <source>Alt+Up</source>
        <translation>Alt+Haut</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="vanished">Page d&apos;accueil</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="564"/>
        <source>Alt+Home</source>
        <translation>Alt+Début / Origine</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="583"/>
        <source>Reload</source>
        <translation>Recharger</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="566"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="563"/>
        <source>&amp;Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="565"/>
        <source>&amp;Reload</source>
        <translation>&amp;Recharger</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="567"/>
        <source>Go</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="568"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="569"/>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="572"/>
        <source>New Window</source>
        <translation>Nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="574"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="575"/>
        <source>Show &amp;Hidden</source>
        <translation>Afficher les éléments cac&amp;hés</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="576"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="577"/>
        <source>&amp;Computer</source>
        <translation>&amp;Ordinateur</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="578"/>
        <source>&amp;Trash</source>
        <translation>&amp;Corbeille</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="579"/>
        <source>&amp;Network</source>
        <translation>&amp;Réseau</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="580"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Bureau</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="581"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Ajouter aux signets</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="582"/>
        <source>&amp;Applications</source>
        <translation>&amp;Applications</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="589"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="590"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="591"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="592"/>
        <source>&amp;Paste</source>
        <translation>&amp;Coller</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="593"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="594"/>
        <source>Select &amp;All</source>
        <translation>Tout sélect&amp;ionner</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="596"/>
        <source>Pr&amp;eferences</source>
        <translation>Préfér&amp;ences</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="597"/>
        <source>&amp;Ascending</source>
        <translation>&amp;Croissant</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="598"/>
        <source>&amp;Descending</source>
        <translation>&amp;Décroissant</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="599"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Par nom de fichier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="600"/>
        <source>By &amp;Modification Time</source>
        <translation>Par date de &amp;modification</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="601"/>
        <source>By File &amp;Type</source>
        <translation>Par &amp;type de fichier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="602"/>
        <source>By &amp;Owner</source>
        <translation>Par &amp;Propriétaire</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="603"/>
        <source>&amp;Folder First</source>
        <translation>&amp;Dossiers d&apos;abord</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Inverser la sélection</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="620"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="622"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="629"/>
        <source>&amp;Case Sensitive</source>
        <translation>Sensible à la &amp;casse</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="630"/>
        <source>By File &amp;Size</source>
        <translation>Par &amp;taille de fichier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="631"/>
        <source>&amp;Close Window</source>
        <translation>&amp;Fermer la fenêtre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="595"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="558"/>
        <source>Go &amp;Up</source>
        <translation>Mon&amp;ter</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="570"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="584"/>
        <source>&amp;Icon View</source>
        <translation>Vue en &amp;icônes</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="585"/>
        <source>&amp;Compact View</source>
        <translation>Vue &amp;compacte</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="586"/>
        <source>&amp;Detailed List</source>
        <translation>Liste &amp;détaillée</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="587"/>
        <source>&amp;Thumbnail View</source>
        <translation>Vue en vigne&amp;ttes</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="588"/>
        <source>Cu&amp;t</source>
        <translation>Cou&amp;per</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="vanished">Ascendant</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="vanished">Descendant</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation type="vanished">Par nom de fichier</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation type="vanished">Par date de modification</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation type="vanished">Par type de fichier</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation type="vanished">Par propriétaire</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation type="vanished">Dossier en premier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="604"/>
        <source>New &amp;Tab</source>
        <translation>Nouvel ongle&amp;t</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="606"/>
        <source>New Tab</source>
        <translation>Nouvel onglet</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="608"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="609"/>
        <source>Go &amp;Back</source>
        <translation>Re&amp;culer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="611"/>
        <source>Go Back</source>
        <translation>Reculer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="613"/>
        <source>Alt+Left</source>
        <translation>Alt+Gauche</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="614"/>
        <source>Go &amp;Forward</source>
        <translation>Ava&amp;ncer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="616"/>
        <source>Go Forward</source>
        <translation>Avancer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="618"/>
        <source>Alt+Right</source>
        <translation>Alt+Droite</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="621"/>
        <source>Del</source>
        <translation>Suppr</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="623"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="624"/>
        <source>C&amp;lose Tab</source>
        <translation>Fermer &amp;l&apos;onglet</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="626"/>
        <source>File &amp;Properties</source>
        <translation>&amp;Propriétés du fichier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="628"/>
        <source>&amp;Folder Properties</source>
        <translation>Propriétés du &amp;dossier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="638"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maj+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="640"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="643"/>
        <source>Filter</source>
        <translation>Filtrer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="646"/>
        <source>C&amp;reate New</source>
        <translation>Créer un &amp;nouveau</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="649"/>
        <source>&amp;Sorting</source>
        <translation>Tri en cour&amp;s</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="654"/>
        <source>Main Toolbar</source>
        <translation>Barre d&apos;outils principale</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="625"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="627"/>
        <source>Alt+Return</source>
        <translation>Alt+Entrée</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="vanished">Sensible à la casse</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation type="vanished">Par taille de fichier</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="vanished">Fermer la fenêtre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="632"/>
        <source>Edit Bookmarks</source>
        <translation>Modifier les signets</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="633"/>
        <source>Open &amp;Terminal</source>
        <translation>Ouvrir le &amp;terminal</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="634"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="635"/>
        <source>Open as &amp;Root</source>
        <translation>Ouvrir en tant que &amp;root</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="636"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>Modifi&amp;er les signets</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="637"/>
        <source>&amp;Folder</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="639"/>
        <source>&amp;Blank File</source>
        <translation>&amp;Fichier vide</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="641"/>
        <source>&amp;Find Files</source>
        <translation>&amp;Trouver des fichiers</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="642"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="644"/>
        <source>Filter by string...</source>
        <translation>Filtrer par chaîne…</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="645"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="647"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="648"/>
        <source>&amp;View</source>
        <translation>&amp;Affichage</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="650"/>
        <source>&amp;Edit</source>
        <translation>&amp;Édition</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="651"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Signets</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="652"/>
        <source>&amp;Go</source>
        <translation>A&amp;ller à…</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="653"/>
        <source>&amp;Tool</source>
        <translation>Ou&amp;tils</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>Name of configuration profile</source>
        <translation>Nom du profil de configuration</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>PROFILE</source>
        <translation>PROFIL</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="165"/>
        <source>Run PCManFM as a daemon</source>
        <translation>Lancer PCManFM comme démon</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="168"/>
        <source>Quit PCManFM</source>
        <translation>Quitter PCManFM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="171"/>
        <source>Launch desktop manager</source>
        <translation>Lancer le gestionnaire de bureau</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="174"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Éteindre le gestionnaire de bureau s&apos;il fonctionne</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Ouvrir la boîte de dialogue des préférences du bureau sur la page avec le nom spécifié</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <location filename="../application.cpp" line="193"/>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Définir le fond d&apos;écran de bureau depuis l&apos;image FILE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>FILE</source>
        <translation>FILE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation>Définir le mode de fond d&apos;écran de bureau. MODE=(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>MODE</source>
        <translation>MODE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Ouvrir la boîte de dialogue des préférences sur la page avec le nom spécifié</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="180"/>
        <source>Open new window</source>
        <translation>Ouvrir une nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="183"/>
        <source>Open Find Files utility</source>
        <translation>Ouvrir l&apos;utilitaire de recherche de fichiers</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2, etc.]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Files or directories to open</source>
        <translation>Fichiers ou dossiers à ouvrir</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="500"/>
        <location filename="../application.cpp" line="507"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="507"/>
        <source>Terminal emulator is not set.</source>
        <translation>L&apos;émulateur de terminal n&apos;est pas défini.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="43"/>
        <source>Open in file manager</source>
        <translation>Ouvrir dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="133"/>
        <source>Removable Disk</source>
        <translation>Disque amovible</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="50"/>
        <source>Fill with background color only</source>
        <translation>Remplir seulement avec la couleur d&apos;arrière-plan</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="51"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Étirer pour remplir l&apos;écran entier</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Stretch to fit the screen</source>
        <translation>Étirer pour remplir l&apos;écran</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Center on the screen</source>
        <translation>Centrer sur l’écran</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Faire une mosaïque avec l&apos;image pour remplir l&apos;écran entier</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="157"/>
        <source>Image Files</source>
        <translation>Fichiers image</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="366"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>Res&amp;ter à la position actuelle</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="388"/>
        <source>Desktop Preferences</source>
        <translation>Préférences du bureau</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Effacer le texte (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mettre à la corbeille</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Switch user command is not set.</source>
        <translation>La commande de changement d’utilisateur n&apos;est pas configurée.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="190"/>
        <source>Icon View</source>
        <translation>Vue en icônes</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="191"/>
        <source>Compact Icon View</source>
        <translation>Vue compacte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="192"/>
        <source>Thumbnail View</source>
        <translation>Vue en vignettes</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="193"/>
        <source>Detailed List View</source>
        <translation>Vue en liste détaillée</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="248"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="261"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Espace libre: %1 (total : %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="276"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n élément</numerusform>
            <numerusform>%n éléments</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="278"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n caché)</numerusform>
            <numerusform> (%n cachés)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="426"/>
        <source>%1 item(s) selected</source>
        <translation>%1 élément(s) sélectionné(s)</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="103"/>
        <source>Open in New T&amp;ab</source>
        <translation>Ouvrir dans un nouvel ongle&amp;t</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="107"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Ouvrir &amp;dans une nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>Ouvrir dans &amp;le terminal</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="706"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="715"/>
        <source>User Interface</source>
        <translation>Interface utilisateur</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="711"/>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="717"/>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="779"/>
        <source>Thumbnail</source>
        <translation>Vignette</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="719"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="721"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="742"/>
        <source>Icons</source>
        <translation>Icônes</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="744"/>
        <source>Size of big icons:</source>
        <translation>Taille des grandes icônes :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="745"/>
        <source>Size of small icons:</source>
        <translation>Taille des petites icônes :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="746"/>
        <source>Size of thumbnails:</source>
        <translation>Taille des vignettes :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="747"/>
        <source>Size of side pane icons:</source>
        <translation>Taille des icônes de panneau latéral :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="743"/>
        <source>Icon theme:</source>
        <translation>Thème d&apos;icônes : </translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="753"/>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="757"/>
        <source>Default width of new windows:</source>
        <translation>Largeur par défaut des nouvelles fenêtres :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="758"/>
        <source>Default height of new windows:</source>
        <translation>Hauteur par défaut des nouvelles fenêtres :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="754"/>
        <source>Always show the tab bar</source>
        <translation>Toujours afficher la barre des onglets</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="755"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Afficher le bouton « Fermer » sur les onglets	</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="756"/>
        <source>Remember the size of the last closed window</source>
        <translation>Mémoriser la taille de la dernière fenêtre fermée</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="724"/>
        <source>Browsing</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="725"/>
        <source>Open files with single click</source>
        <translation>Ouvrir les fichiers avec un simple clic</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="726"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Délai avant auto-sélection en mode simple click (0 pour désactiver)</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="727"/>
        <source>Default view mode:</source>
        <translation>Mode d&apos;affichage par défaut :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="728"/>
        <source> sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="736"/>
        <source>File Operations</source>
        <translation>Opérations sur les fichiers</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="737"/>
        <source>Confirm before deleting files</source>
        <translation>Confirmer avant de supprimer les fichiers</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="738"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Mettre les fichiers supprimés à la corbeille eu lieu de les effacer du disque.</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="783"/>
        <source>Show thumbnails of files</source>
        <translation>Montrer les vignettes des fichiers</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="782"/>
        <source>Only show thumbnails for local files</source>
        <translation>Montrer les vignettes seulement pour les fichiers locaux</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="713"/>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="729"/>
        <source>Bookmarks:</source>
        <translation>Marque-pages :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="732"/>
        <source>Open in current tab</source>
        <translation>Ouvrir dans l&apos;onglet courant</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="733"/>
        <source>Open in new tab</source>
        <translation>Ouvrir dans un nouvel onglet</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="734"/>
        <source>Open in new window</source>
        <translation>Ouvrir dans une nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="739"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="740"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Confirmer avant de déplacer des fichiers à la poubelle</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="741"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>Ne pas poser de questions avant lancement de fichier exécutable</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="748"/>
        <source>User interface</source>
        <translation>Interface utilisateur</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="750"/>
        <source>Treat backup files as hidden</source>
        <translation>Cacher les fichiers de sauvegarde</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="751"/>
        <source>Always show full file names</source>
        <translation>Toujours montrer le nom complet des fichiers</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="752"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Montrer les icônes de fichiers cachés ombragées</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="759"/>
        <source>Show in places</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="764"/>
        <source>Home</source>
        <translation>Page d&apos;accueil</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="766"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="768"/>
        <source>Trash can</source>
        <translation>Poubelle</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="770"/>
        <source>Computer</source>
        <translation>Ordinateur</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="772"/>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="774"/>
        <source>Devices</source>
        <translation>Périphériques</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="776"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="780"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>Ne pas générer de vignettes pour les fichiers image excédant cette taille :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="781"/>
        <source> KB</source>
        <translation> Ko</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="784"/>
        <source>Auto Mount</source>
        <translation>Monter automatiquement</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="785"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Monter automatiquement les volumes au démarrage du programme</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="786"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Monter automatiquement les médias amovibles lorsqu&apos;ils sont insérés</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="787"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Montrer les options disponibles pour les médias amovibles lorsqu&apos;ils sont insérés</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="788"/>
        <source>When removable medium unmounted:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="789"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="790"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="793"/>
        <source>Switch &amp;user command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="796"/>
        <source>Archiver in&amp;tegration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="797"/>
        <source>Templates</source>
        <translation>Modèles</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="798"/>
        <source>Show only user defined templates in menu</source>
        <translation>Ne montrer que les modèles définis par l&apos;utilisateur dans le menu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="799"/>
        <source>Show only one template for each MIME type</source>
        <translation>Ne montrer qu&apos;un modèle pour chaque type MIME</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="800"/>
        <source>Run default application after creation from template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="791"/>
        <source>Programs</source>
        <translation>Programmes</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="792"/>
        <source>Terminal emulator:</source>
        <translation>Émulateur de terminal :</translation>
    </message>
    <message>
        <source>Switch user command:</source>
        <translation type="vanished">Commande de changement d&apos;utilisateur :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="794"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>Exemples : « xterm -e %s » pour le terminal ; « gksu %s » pour changer d’utilisateur.
%s = la ligne de commande que vous voulez exécuter avec le terminal ou su.</translation>
    </message>
    <message>
        <source>Archiver integration:</source>
        <translation type="vanished">Intégration du logiciel de compression de données :</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="749"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Utiliser les préfixes de décimales du système international d&apos;unités au lieu des préfixes binaires de l&apos;IEC</translation>
    </message>
</context>
</TS>
